@@ -9,9 +9,12 @@ from core_main_app.permissions.utils import get_formatted_name
 
 class Curate(models.Model):
     class Meta(object):
-        verbose_name = 'core_curate_app'
+        verbose_name = "core_curate_app"
         default_permissions = ()
         permissions = (
             (rights.curate_access, get_formatted_name(rights.curate_access)),
-            (rights.curate_view_data_save_repo, get_formatted_name(rights.curate_view_data_save_repo)),
+            (
+                rights.curate_view_data_save_repo,
+                get_formatted_name(rights.curate_view_data_save_repo),
+            ),
         )
