@@ -12,7 +12,7 @@ import core_main_app.utils.decorators as decorators
 from core_curate_app.components.curate_data_structure import (
     api as curate_data_structure_api,
 )
-from core_curate_app.settings import INSTALLED_APPS
+from core_curate_app.settings import INSTALLED_APPS, ENABLE_XML_ENTITIES_TOOLTIPS
 from core_curate_app.utils.parser import get_parser
 from core_main_app.commons.exceptions import LockError, ModelError, DoesNotExist
 from core_main_app.access_control.exceptions import AccessControlError
@@ -38,7 +38,7 @@ logger = logging.getLogger(__name__)
     login_url=reverse_lazy("core_main_app_login"),
 )
 def index(request):
-    """ Page that allows to select a template to start curating.
+    """Page that allows to select a template to start curating.
 
     Args:
         request:
@@ -102,6 +102,15 @@ class EnterDataView(View):
                 "core_parser_app/css/use.css",
             ],
         }
+
+        if ENABLE_XML_ENTITIES_TOOLTIPS:
+            self.assets["js"].append(
+                {
+                    "path": "core_curate_app/user/js/xml_entities_tooltip.js",
+                    "is_raw": False,
+                }
+            )
+
         self.modals = [
             "core_curate_app/user/data-entry/modals/cancel-changes.html",
             "core_curate_app/user/data-entry/modals/cancel-form.html",
@@ -114,7 +123,7 @@ class EnterDataView(View):
         ]
 
     def build_context(self, request, curate_data_structure, reload_unsaved_changes):
-        """ Build the context of the view
+        """Build the context of the view
 
         Args:
             request:
@@ -425,7 +434,7 @@ def render_xml(root_element):
 
 
 def _get_curate_data_structure_by_id(curate_data_structure_id, request):
-    """ Get the curate data structure by its id.
+    """Get the curate data structure by its id.
 
     Args: curate_data_structure_id:
           request:
